/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 * $Id: contactlist.cpp,v 1.10 2001/05/23 23:54:41 denis Exp $
 * $Log: contactlist.cpp,v $
 * Revision 1.10  2001/05/23 23:54:41  denis
 * Warning cleanup.
 *
 * Revision 1.9  2001/03/03 20:16:14  bills
 * merge from kdenonbeta: faure - 0 is NOT a valid QString
 *
 * Revision 1.8  2000/12/19 06:17:06  bills
 * change icqlink member in regwin and mainwindow to an ICQLINK *, use
 * icq_ICQLINKNew and icq_ICQLINKDelete instead of icq_Init and icq_Done
 *
 * Revision 1.7  2000/11/10 21:14:52  nofate
 * admin/ updated from KDE_2_0_STABLE; i18n messages were updated; fixed call
 * to icq_Init for icqlib
 *
 * Revision 1.6  2000/10/14 21:00:50  davidvh
 * Minor fixes.
 *
 * Revision 1.5  2000/10/02 21:44:06  kir
 * New UConfig code.
 *
 * Revision 1.4  2000/09/30 20:05:40  napalmbox
 * big update
 *
 * Revision 1.3  2000/09/13 19:11:12  napalmbox
 * replase kicq ver 1.0.0 files with kicq ver 2.0.0 files
 *
 * Revision 1.1.2.3  2000/09/02 21:41:12  napalmbox
 * fix fix fix ....a big fix
 *
 * Revision 1.1.2.2  2000/07/22 19:44:03  napalmbox
 * kicq compiles now with -DQT_NO_ASCII_CAST
 *
 * Revision 1.1.2.1  2000/07/02 05:45:54  napalmbox
 * port kicq -> kde2 :))
 *
 * Revision 1.1  2000/06/17 17:38:03  denis
 * Contact List code was rewritten from scratch! Although we are trying
 * to not add new features in anticipation of the next stable release,
 * but this rewrite solves many things, removes many hacks and stabilizes
 * whole program.
 * One of bug, needs to mention, is an absence of IP address in Info
 * window. The root of problem was in Contact List, because in any time
 * there were several ContactItems in memory for single user - they were
 * "smeared" on the whole code. Now it's clean and strict - all Contact
 * List operations can be done only by ContactList class.
 *
 */

#include <stdlib.h>
#include <qdir.h>
#include <kapp.h>
#include <icq.h>

#include "contactlist.h"
#include "mainwindow.h"
#include "uconfigdb.h"

ContactList::ContactList(void) :
  onlineListIterator(onlineList), offlineListIterator(offlineList),
  notInListIterator(notInList)
{
  onlineList.setAutoDelete(TRUE);
  offlineList.setAutoDelete(TRUE);
  notInList.setAutoDelete(TRUE);
  return;
}

ContactList::ContactList(QString dirname) :
  onlineListIterator(onlineList), offlineListIterator(offlineList),
  notInListIterator(notInList)
{
  onlineList.setAutoDelete(TRUE);
  offlineList.setAutoDelete(TRUE);
  notInList.setAutoDelete(TRUE);
  load(dirname);
  return;
}

ContactList::~ContactList(void)
{
  onlineList.clear();
  offlineList.clear();
  notInList.clear();
  return;
}

void ContactList::load(QString okidoki)
{
  yes = okidoki;

  icq_ContactClear(MW->icqlink);
  onlineList.clear();
  offlineList.clear();
  notInList.clear();

  db->setPath(MW->getOwnerPath() + "/Contact List");
//  db->setPath(MW->contactsPath());

  QString uinstr;
  unsigned long uin;
  ContactItem *item;
  for(UCPathIterator it(db); it; ++it)
  {
    uinstr = it.group();
    uin = uinstr.toULong();
    item = new ContactItem(uin, yes);
    offlineList.append(item);
    icq_ContactAdd(MW->icqlink, item->getUIN());
    icq_ContactSetVis(MW->icqlink, item->getUIN(), item->isVisible());
  }
  MW->updateVisibleList();
  return;
}

void ContactList::save(void)
{
  return;
}

void ContactList::setStatusByUIN(unsigned long uin, unsigned long status)
{
  ContactItem *ptr, *usritem;
  for(ptr = offlineList.first(); ptr; ptr = offlineList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->setStatus(status);
      if(status != (unsigned long)STATUS_OFFLINE)
      {
        usritem = offlineList.take();
        onlineList.insert(0, usritem);
      }
    }
  for(ptr = onlineList.first(); ptr; ptr = onlineList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->setStatus(status);
      if(status == (unsigned long)STATUS_OFFLINE)
      {
        usritem = onlineList.take();
        offlineList.insert(0, usritem);
      }
    }
  MW->updateVisibleList();
  return;
}

void ContactList::appendItem(ContactItem *item)
{
  item->setStatus((unsigned long)STATUS_OFFLINE);
  offlineList.append(item);
  item->save();
  MW->updateVisibleList();
  return;
}

void ContactList::appendNILItem(ContactItem *item)
{
  item->setStatus((unsigned long)STATUS_OFFLINE);
  notInList.append(item);
  MW->updateVisibleList();
  return;
}

void ContactList::deleteByUIN(unsigned long uin)
{
  ContactItem *ptr;
  for(ptr = offlineList.first(); ptr; ptr = offlineList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->remove();
      offlineList.removeRef(ptr);
    }
  for(ptr = onlineList.first(); ptr; ptr = onlineList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->remove();
      onlineList.removeRef(ptr);
    }
  MW->updateVisibleList();
  return;
}

void ContactList::deleteNILByUIN(unsigned long uin)
{
  ContactItem *ptr;
  for(ptr = notInList.first(); ptr; ptr = notInList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->remove();
      notInList.removeRef(ptr);
    }
  MW->updateVisibleList();
  return;
}

void ContactList::addToContactListByUIN(unsigned long uin)
{
  ContactItem *ptr, *usritem;
  for(ptr = notInList.first(); ptr; ptr = notInList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->save();
      usritem = notInList.take();
      offlineList.insert(0, usritem);
    }
  MW->updateVisibleList();
  return;
}

void ContactList::addNewToContactListByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
  {
    addToContactListByUIN(uin);
    if(MW->isLogged())
      icq_SendNewUser(MW->icqlink, uin);
    MW->updateVisibleList();
  }
  return;
}

void ContactList::addMsg(unsigned long uin, icqMessage *msg)
{
// FIXME: Remove printf()
  if(!msg)
    printf("UserList::addMsg(uin=%lu, msg=0L)\n", uin);
  ContactItem *ptr;
  for(ptr = offlineList.first(); ptr; ptr = offlineList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->addMsg(msg);
      MW->updateVisibleList();
      return;
    }
  for(ptr = onlineList.first(); ptr; ptr = onlineList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->addMsg(msg);
      MW->updateVisibleList();
      return;
    }
  /* User is not in the list */
  for(ptr = notInList.first(); ptr; ptr = notInList.next())
    if(ptr->getUIN() == uin)
    {
      ptr->addMsg(msg);
      MW->updateVisibleList();
      return;
    }
  /* User is not even in the 'Not in list' list :) */
  ContactItem *ci = new ContactItem(uin);
  notInList.append(ci);

  if(MW->isLogged())
    icq_SendInfoReq(MW->icqlink, uin);
  ci->addMsg(msg);
  MW->updateVisibleList();
  return;
}

void ContactList::addMsg(unsigned long uin, TimeStr time, const char *body)
{
  icqMessage *msg = new icqMessage(uin, time, QString::fromLocal8Bit( body ), MSG_RECV);
  addMsg(uin, msg);
  return;
}

void ContactList::addURL(unsigned long uin, TimeStr time, const char *url, const char *desc)
{
  icqMessage *msg = new icqMessage(uin, time, url, desc, MSG_URL_RECV);
  addMsg(uin, msg);
  return;
}

void ContactList::addAuth(unsigned long uin, TimeStr time, const char *nick, const char *first, 
                       const char *last,const char *email,const char *reason)
{
  icqMessage *msg = new icqMessage(uin, time, nick, first, last, email, reason, MSG_AUTH_RECV);
  addMsg(uin, msg);
  return;
}

void ContactList::addAdded(unsigned long uin, TimeStr time, const char *nick, 
                        const char *first, const char *last,const char *email)
{
  icqMessage *msg = new icqMessage(uin, time, nick, first, last, email, MSG_ADDED);
  addMsg(uin, msg);
  return;
}

void ContactList::addPager(unsigned long uin, TimeStr time, const char *nick, const char *email,
                        const char *body)
{
  icqMessage *msg = new icqMessage(uin, time, nick, email, body, MSG_PAGER_RECV);
  addMsg(uin, msg);
  return;
}

void ContactList::addExpress(unsigned long uin, TimeStr time, const char *nick, const char *email,
                          const char *body)
{
  icqMessage *msg = new icqMessage(uin, time, nick, email, body, MSG_EXPRESS_RECV);
  addMsg(uin, msg);
  return;
}

void ContactList::addChatReq(unsigned long uin, TimeStr time, const char *desc, unsigned long seq)
{
  icqMessage *msg = new icqMessage(uin, time, desc, seq, MSG_CHAT_REQ_RECV);
  addMsg(uin, msg);
  return;
}

void ContactList::addFileReq(unsigned long uin, TimeStr time, const char *text,
                          const char *file, unsigned long size, unsigned long seq)
{
  icqMessage *msg = new icqMessage(uin, time, text, file, size, seq, MSG_FILE_REQ_RECV);
  addMsg(uin, msg);
  return;
}

void ContactList::updateInfoByUIN(unsigned long uin, QString nick, QString first,
                                  QString last, QString email, char auth)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
    ptr->updateInfo(nick, first, last, email, auth);
  if(isUINInContactList(uin))
    ptr->save();
  MW->updateVisibleList();
  return;
}

void ContactList::updateExtInfoByUIN(unsigned long uin, QString city, unsigned short country_code,
                                     char country_stat, QString state, unsigned short age,
                                     char gender, QString phone, QString hp, QString about)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
    ptr->updateExtInfo(city, country_code, country_stat, state, age, gender, phone, hp, about);
  if(isUINInContactList(uin))
    ptr->save();
  MW->updateVisibleList();
  return;
}

void ContactList::userOnlineByUIN(unsigned long uin, unsigned long status, unsigned long ip,
                                  unsigned short port, unsigned long r_ip, unsigned char tcp_flag)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
  {
    setStatusByUIN(uin, status);
    ptr->setLastIP(ip);
    ptr->setRealIP(r_ip);
    ptr->setPort(port);
    ptr->setTCPFlag(tcp_flag);
//     printf("ContactList: IP = %lu\n", ptr->getLastIP());
//     printf("ContactList - 2: IP = %lu\n", getLastIPByUIN(uin));
  }
  MW->updateVisibleList();
  return;
}
/*
void ContactList::saveInfoByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
    ptr->save(contdir);
  return;
}
*/
void ContactList::setAllOffline(void)
{
  ContactItem *ptr, *usritem;
  for(ptr = onlineList.first(); ptr; ptr = onlineList.first())
  {
    ptr->setStatus((unsigned long)STATUS_OFFLINE);
    usritem = onlineList.take();
    offlineList.insert(0, usritem);
  }
  MW->updateVisibleList();
  return;
}

QString ContactList::getNickByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getNick() : i18n("Unknown");
}

QString ContactList::getEMailByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getEMail() : i18n("Unknown");
}

QString ContactList::getNameByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getName() : i18n("Unknown");
}

lastEvent ContactList::getMsgLastByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getMsgLast() : LAST_NONE;
}

unsigned long ContactList::getStatusByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getStatus() : (unsigned long)STATUS_OFFLINE;
}

unsigned long ContactList::getLastIPByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getLastIP() : 0;
}

bool ContactList::getOnlineAlertByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->isOnlineAlert() : FALSE;
}

bool ContactList::getVisibleUserByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->isVisible() : FALSE;
}

icqMsgType ContactList::getFirstUnreadMsgTypeByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getFirstUnreadMsgType() : MSG_UNDEF;
}

int ContactList::getNumUnreadMsgsByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getNumUnreadMsgs() : 0;
}

QString ContactList::getAboutByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getAbout() : QString::null;
}

QString ContactList::getNotesByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getNotes() : QString::null;
}

QList<icqMessage> *ContactList::getMsgListByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->getMsgList() : 0;
}

bool ContactList::isUINOffline(unsigned long uin)
{
  ContactItem *ptr;
  for(ptr = offlineList.first(); ptr; ptr = offlineList.next())
    if(ptr->getUIN() == uin)
      return TRUE;
  return FALSE;
}

bool ContactList::isUINOnline(unsigned long uin)
{
  ContactItem *ptr;
  for(ptr = onlineList.first(); ptr; ptr = onlineList.next())
    if(ptr->getUIN() == uin)
      return TRUE;
  return FALSE;
}

bool ContactList::isUINNotInList(unsigned long uin)
{
  ContactItem *ptr;
  for(ptr = notInList.first(); ptr; ptr = notInList.next())
    if(ptr->getUIN() == uin)
      return TRUE;
  return FALSE;
}

bool ContactList::isUINInContactList(unsigned long uin)
{
  return (isUINOnline(uin)) ? TRUE : isUINOffline(uin);
}

const ContactItem *ContactList::getInfoByUIN(unsigned long uin)
{
  return getInfoPtrByUIN(uin);
}

ContactItem *ContactList::getInfoPtrByUIN(unsigned long uin)
{
  ContactItem *ptr;
  for(ptr = offlineList.first(); ptr; ptr = offlineList.next())
    if(ptr->getUIN() == uin)
      return ptr;
  for(ptr = onlineList.first(); ptr; ptr = onlineList.next())
    if(ptr->getUIN() == uin)
      return ptr;
  for(ptr = notInList.first(); ptr; ptr = notInList.next())
    if(ptr->getUIN() == uin)
      return ptr;
  return 0;
}

void ContactList::setAliasByUIN(unsigned long uin, QString alias)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
    ptr->setAlias(alias);
  if(isUINInContactList(uin))
    ptr->save();
  MW->updateVisibleList();
  return;
}

void ContactList::setNotesByUIN(unsigned long uin, QString notes)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
    ptr->setNotes(notes);
  if(isUINInContactList(uin))
    ptr->save();
  return;
}

void ContactList::toggleOnlineAlertByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
    ptr->setOnlineAlert(!ptr->isOnlineAlert());
  if(isUINInContactList(uin))
    ptr->save();
  MW->updateVisibleList();
  return;
}

void ContactList::toggleVisibleUserByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(!ptr)
    return;
  ptr->setVisible(!ptr->isVisible());
  icq_ContactSetVis(MW->icqlink, uin, ptr->isVisible());

  if(isUINInContactList(uin))
    ptr->save();
  MW->updateVisibleList();
  return;
}

void ContactList::setThruServerByUIN(unsigned long uin, bool ts)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  if(ptr)
    ptr->setThruServer(ts);
  return;
}

bool ContactList::getThruServerByUIN(unsigned long uin)
{
  ContactItem *ptr = getInfoPtrByUIN(uin);
  return (ptr) ? ptr->isThruServer() : FALSE;
}
