/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
// $Id: renwindow.cpp,v 1.6 2000/10/14 21:00:50 davidvh Exp $
// $Log: renwindow.cpp,v $
// Revision 1.6  2000/10/14 21:00:50  davidvh
// Minor fixes.
//
// Revision 1.5  2000/10/13 22:08:57  napalmbox
// clean up "magic" resize(1,1)
//
// Revision 1.4  2000/10/07 22:53:04  napalmbox
// clean up layout->activate() and "magic" resize(1,1) - not need for QT2.2.X up
//
// Revision 1.3  2000/09/13 19:11:12  napalmbox
// replase kicq ver 1.0.0 files with kicq ver 2.0.0 files
//
// Revision 1.2.2.1  2000/07/22 19:47:59  napalmbox
// kicq now compiles with -DQT_NO_ASCII_CAST
//
// Revision 1.2  2000/06/17 17:38:22  denis
// Contact List code was rewritten from scratch! Although we are trying
// to not add new features in anticipation of the next stable release,
// but this rewrite solves many things, removes many hacks and stabilizes
// whole program.
// One of bug, needs to mention, is an absence of IP address in Info
// window. The root of problem was in Contact List, because in any time
// there were several ContactItems in memory for single user - they were
// "smeared" on the whole code. Now it's clean and strict - all Contact
// List operations can be done only by ContactList class.
//
// Revision 1.1  2000/05/24 16:57:16  denis
// Sources have been splitted to the whole bunch of appropriate
// directories. Every directory is end up with static library. All
// of them are linked together to the final kicq binary.
//
// Revision 1.8  1999/12/02 14:26:02  denis
// Random IcqWindow segfaults fixed.
// Cleanups.
//
// Revision 1.7  1999/10/14 12:58:38  denis
// QLayout support implemented.
// Segfault on window close fixed.
//
// Revision 1.6  1999/07/16 15:48:56  denis
// Cleaned up.
//
// Revision 1.5  1999/07/16 13:12:25  denis
// Internalization support added.
//
// Revision 1.4  1999/04/17 20:22:23  bills
// modified for new icqwindow base class
//
// Revision 1.3  1998/12/08 16:29:48  denis
// Cleaned up a little before releasing
//

#include <qlayout.h>
#include <qlabel.h>
#include <qpushbt.h>

#include "renwindow.h"
#include "mainwindow.h"

#include "renwindow.moc"

RenameWindow::RenameWindow(QString name, unsigned long puin, QString nick, QString first,
                           QString last, QString email) : IcqWindow()
{
  CrashGuard();
  setCaption(i18n("Rename User"));

  QString txt;
  txt.sprintf("Rename user %s to:", name.latin1());
  uin = puin;

  topLayout = new QVBoxLayout(this, 7);

  label = new QLabel(txt,this);
  label->setMinimumSize(label->sizeHint());
  topLayout->addWidget(label);

  aliasBox = new QComboBox(TRUE, this);
  aliasBox->setMinimumSize(aliasBox->sizeHint());
  aliasBox->setMaximumHeight(aliasBox->sizeHint().height());
  aliasBox->setInsertionPolicy(QComboBox::NoInsertion);
  if(!nick.isEmpty() && nick!=i18n("N/A"))
    aliasBox->insertItem(nick);
  if(!first.isEmpty() && first!=i18n("N/A") && first!=nick)
    aliasBox->insertItem(first);
  if(!last.isEmpty() && last!=i18n("N/A") && last!=nick)
    aliasBox->insertItem(last);
  if(!first.isEmpty() && !last.isEmpty() && first!=i18n("N/A") && last!=i18n("N/A"))
    aliasBox->insertItem(first+" "+last);
  if(!email.isEmpty() && email!=i18n("N/A"))
    aliasBox->insertItem(email);
  txt.setNum(uin);
  aliasBox->insertItem(txt);
  topLayout->addWidget(aliasBox);

  buttonLayout = new QHBoxLayout(7);
  topLayout->addLayout(buttonLayout);

  buttonLayout->addStretch(1);

  okBtn = new QPushButton(i18n("&Ok"), this);
  okBtn->setMaximumHeight(okBtn->sizeHint().height());
  okBtn->setDefault(TRUE);
  connect(okBtn, SIGNAL(clicked()), SLOT(accept()));
  buttonLayout->addWidget(okBtn);

  cancelBtn = new QPushButton(i18n("&Cancel"), this);
  cancelBtn->setMaximumHeight(cancelBtn->sizeHint().height());
  connect(cancelBtn, SIGNAL(clicked()), SLOT(reject()));
  buttonLayout->addWidget(cancelBtn);

  int w = QMAX(okBtn->sizeHint().width(), cancelBtn->sizeHint().width());
  okBtn->setMinimumSize(w, okBtn->sizeHint().height());
  cancelBtn->setMinimumSize(w, cancelBtn->sizeHint().height());

  buttonLayout->addStretch(1);

  aliasBox->setFocus();
  return;
}

RenameWindow::~RenameWindow(void)
{
  RemovePointer(cancelBtn);
  RemovePointer(okBtn);
  RemovePointer(buttonLayout);
  RemovePointer(aliasBox);
  RemovePointer(label);
  RemovePointer(topLayout);
  return;
}

void RenameWindow::CrashGuard(void)
{
  topLayout = 0;
  label = 0;
  aliasBox = 0;
  buttonLayout = 0;
  okBtn = 0;
  cancelBtn = 0;
  return;
}

unsigned long RenameWindow::UIN()
{
  return uin;
}

void RenameWindow::accept(void)
{
  MW->contactList().setAliasByUIN(uin, aliasBox->currentText());
  IcqWindow::accept();
  return;
}

void RenameWindow::done(int p)
{
  IcqWindow::done(p);
  return;
}
