 /***************************************************************************
    description          : pref_conn.cpp
    begin                : Tue Apr 25 2000
    copyright            : (C) 2000 by Florian Veskov
    email                : napalmbox@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "pref_conn.h"
#include <qlayout.h>
#include "main.h"

#include "pref_conn.moc"

UserWidget::UserWidget(QWidget *parent) : QWidget(parent)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);

  topLayout->addSpacing(7);

  QGroupBox *userbox = new QGroupBox(i18n("Current User Settings"), this);

  QBoxLayout *boxLayout = new QVBoxLayout(userbox, 10, 7);

  boxLayout->addSpacing(7);

  QLabel *uinlabel = new QLabel(i18n("ICQ#:"), userbox);
  uinlabel->setMinimumSize(uinlabel->sizeHint());
  boxLayout->addWidget(uinlabel);

  uinline = new KIntegerLine(userbox);
  uinline->setMinimumSize(uinline->sizeHint());
  uinline->setMaximumHeight(uinline->sizeHint().height());
  boxLayout->addWidget(uinline, 1);

  QLabel *nicklabel = new QLabel(i18n("Nick Name:"), userbox);
  nicklabel->setMinimumSize(nicklabel->sizeHint());
  boxLayout->addWidget(nicklabel);

  nickline = new QLineEdit(userbox);
  nickline->setMinimumSize(nickline->sizeHint());
  nickline->setMaximumHeight(nickline->sizeHint().height());
  boxLayout->addWidget(nickline, 1);

  QLabel *passlabel = new QLabel(i18n("Password:"), userbox);
  passlabel->setMinimumSize(passlabel->sizeHint());
  boxLayout->addWidget(passlabel);

  passline = new QLineEdit(userbox);
  passline->setEchoMode(QLineEdit::Password);
  passline->setMinimumSize(passline->sizeHint());
  passline->setMaximumHeight(passline->sizeHint().height());
  boxLayout->addWidget(passline, 1);

  topLayout->addWidget(userbox);

  topLayout->addStretch(1);
}

void UserWidget::setInfo(unsigned long uin, const QString &nick, const QString &pass)
{
  uinline->setValue(uin);
  nickline->setText(nick);
  passline->setText(pass);
}

ServerWidget::ServerWidget(QWidget *parent) : QWidget(parent)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);

  topLayout->addSpacing(7);

  QGroupBox *serverbox = new QGroupBox(i18n("ICQ Server"), this);

  QBoxLayout *boxLayout = new QVBoxLayout(serverbox, 10, 7);

  boxLayout->addSpacing(7);

  QLabel *hostlabel = new QLabel(i18n("Server:"), serverbox);
  hostlabel->setMinimumSize(hostlabel->sizeHint());
  boxLayout->addWidget(hostlabel);

  hostline = new QComboBox(true,serverbox);
  hostline->setMinimumSize(hostline->sizeHint());
  hostline->setMaximumHeight(hostline->sizeHint().height());
  hostline->insertItem("icq.mirabilis.com");
  hostline->insertItem("icq1.mirabilis.com");
  hostline->insertItem("icq.fes.mirabilis.com");
  hostline->insertItem("205.188.179.39");
  hostline->insertItem("205.188.179.42");

  boxLayout->addWidget(hostline, 1);

  QLabel *portlabel = new QLabel(i18n("Port:"), serverbox);
  portlabel->setMinimumSize(portlabel->sizeHint());
  boxLayout->addWidget(portlabel);

  portline = new KIntegerLine(serverbox);
  portline->setMinimumSize(portline->sizeHint());
  portline->setMaximumHeight(portline->sizeHint().height());
  boxLayout->addWidget(portline, 1);

  topLayout->addWidget(serverbox);
  topLayout->addStretch(1);
}

void ServerWidget::setInfo(const QString &host, int port)
{
  hostline->setEditText(host);
  portline->setValue(port);
}


/////////////////////////////////////////////////////////////////////////////////////////////////////////////
ProxyWidget::ProxyWidget(QWidget *parent) : QWidget(parent)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);

  QGroupBox *proxybox = new QGroupBox(i18n("SOCKS5 Proxy"), this);

  QBoxLayout *boxLayout = new QVBoxLayout(proxybox, 10, 7);

  boxLayout->addSpacing(7);

  usebox = new QCheckBox(i18n("Use SOCKS5 Proxy"), proxybox);
  connect(usebox, SIGNAL(toggled(bool)), SLOT(useToggled(bool)));
  usebox->setMinimumSize(usebox->sizeHint());
  boxLayout->addWidget(usebox);

  QLabel *hostlabel = new QLabel(i18n("Server:"), proxybox);
  hostlabel->setMinimumSize(hostlabel->sizeHint());
  boxLayout->addWidget(hostlabel);

  hostline = new QLineEdit(proxybox);
  hostline->setMinimumSize(hostline->sizeHint());
  hostline->setMaximumHeight(hostline->sizeHint().height());
  boxLayout->addWidget(hostline, 1);

  QLabel *portlabel = new QLabel(i18n("Port:"), proxybox);
  portlabel->setMinimumSize(portlabel->sizeHint());
  boxLayout->addWidget(portlabel);

  portline = new KIntegerLine(proxybox);
  portline->setMinimumSize(portline->sizeHint());
  portline->setMaximumHeight(portline->sizeHint().height());
  boxLayout->addWidget(portline, 1);

  authbox = new QCheckBox(i18n("RFC1929 Username/Password Authentication"), proxybox);
  connect(authbox, SIGNAL(toggled(bool)), SLOT(authToggled(bool)));
  authbox->setMinimumSize(authbox->sizeHint());
  boxLayout->addWidget(authbox);

  QLabel *userlabel = new QLabel(i18n("User:"), proxybox);
  userlabel->setMinimumSize(userlabel->sizeHint());
  boxLayout->addWidget(userlabel);

  userline = new QLineEdit(proxybox);
  userline->setMinimumSize(userline->sizeHint());
  userline->setMaximumHeight(userline->sizeHint().height());
  boxLayout->addWidget(userline, 1);

  QLabel *passlabel = new QLabel(i18n("Password:"), proxybox);
  passlabel->setMinimumSize(passlabel->sizeHint());
  boxLayout->addWidget(passlabel);

  passline = new QLineEdit(proxybox);
  passline->setEchoMode(QLineEdit::Password);
  passline->setMinimumSize(passline->sizeHint());
  passline->setMaximumHeight(passline->sizeHint().height());
  boxLayout->addWidget(passline, 1);

  topLayout->addWidget(proxybox);
  topLayout->addStretch(1);
}

void ProxyWidget::setInfo(int use, const QString &host, int port, int auth, const QString &user, const QString &pass)
{
  usebox->setChecked(use);
  hostline->setText(host);
  portline->setValue(port);
  authbox->setChecked(auth);
  userline->setText(user);
  passline->setText(pass);
  if(!use)
  {
    hostline->setEnabled(FALSE);
    portline->setEnabled(FALSE);
    authbox->setEnabled(FALSE);
    userline->setEnabled(FALSE);
    passline->setEnabled(FALSE);
  }
  if(!auth)
  {
    userline->setEnabled(FALSE);
    passline->setEnabled(FALSE);
  }
}


void ProxyWidget::useToggled(bool p)
{
  if(p)
  {
    hostline->setEnabled(TRUE);
    portline->setEnabled(TRUE);
    authbox->setEnabled(TRUE);
    if(authbox->isChecked())
    {
      userline->setEnabled(TRUE);
      passline->setEnabled(TRUE);
    }
    else
    {
      userline->setEnabled(FALSE);
      passline->setEnabled(FALSE);
    }
  }
  else
  {
    hostline->setEnabled(FALSE);
    portline->setEnabled(FALSE);
    authbox->setEnabled(FALSE);
    userline->setEnabled(FALSE);
    passline->setEnabled(FALSE);
  }
}

void ProxyWidget::authToggled(bool p)
{
  if(p)
  {
    userline->setEnabled(TRUE);
    passline->setEnabled(TRUE);
  }
  else
  {
    userline->setEnabled(FALSE);
    passline->setEnabled(FALSE);
  }
}
////////////////////////////////////////////////////////////////////////////////////////////////////////////
ConnTab::ConnTab(QWidget *parent, const char *name)
: QTabWidget(parent, name)
{

}

Connections::Connections(QWidget *parent, const char *name)
: QWidget(parent, name)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);
  QLabel *mainlabel = new QLabel(i18n(" Connections"),this);
  mainlabel->setFont(QFont("Helvetica", 12, QFont::Bold, FALSE));
   QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 0, 37, 172) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 237, 237, 237) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 0, 37, 172) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 253, 253, 253) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 253, 253, 253) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setDisabled( cg );
  mainlabel->setPalette( pal );
  mainlabel->setMinimumSize(mainlabel->sizeHint());
  topLayout->addWidget(mainlabel);
  topLayout->addSpacing(7);
  conntab = new ConnTab(this);
  topLayout->addWidget(conntab);

}



