 /***************************************************************************
    description          : pref_events.cpp
    begin                : Tue Apr 25 2000
    copyright            : (C) 2000 by Florian Veskov
    email                : napalmbox@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qdir.h>
#include <qdict.h>
#include <qlayout.h>

#include "pref_events.h"
#include "mainwindow.h"
#include "icqsound.h"
#include "kwebbrowser.h"

#include "pref_events.moc"

SoundWidget::SoundWidget(QWidget *parent) : QWidget(parent)
{
  QStringList slist;

  QBoxLayout *topLayout = new QVBoxLayout(this);

  topLayout->addSpacing(7);

  QGroupBox *soundbox = new QGroupBox(i18n("Sounds"), this);

  QBoxLayout *boxLayout = new QVBoxLayout(soundbox, 10, 7);

  boxLayout->addSpacing(7);

  QBoxLayout *butLayout = new QHBoxLayout(10);
  boxLayout->addLayout(butLayout);

  wavbox = new QCheckBox(i18n("Play sounds"), soundbox);
  wavbox->setMinimumSize(wavbox->sizeHint());
  butLayout->addWidget(wavbox);

  butLayout->addStretch(1);

  testbutton = new QPushButton(i18n("&Test"), soundbox);
  testbutton->setMinimumSize(testbutton->sizeHint());
  butLayout->addWidget(testbutton);

  QBoxLayout *listLayout = new QHBoxLayout(10);
  boxLayout->addLayout(listLayout, 1);

  soundlist = new QListBox(soundbox);
  soundlist->insertItem("(none)");
  soundlist->insertItem("(beep)");
  soundlist->installEventFilter(soundbox);

  QStringList lst = KGlobal::dirs()->findAllResources("kicq_sounds", QString::fromLatin1("*.wav"));
     QStringList::Iterator it;
    for (it=lst.begin(); it!=lst.end(); it++) {
        int pos = (*it).findRev('/');
        if (pos != -1)
           (*it) = (*it).mid(pos+1);
        }

  soundlist->insertStringList(lst);

  soundlist->setMinimumHeight(150);

  connect(soundlist, SIGNAL(highlighted(int)),
     SLOT(soundSelected(int)));

  IcqSound temp;

  eventlist = new QListBox(soundbox);
  eventlist->insertStrList(&(temp.eventList));
  eventlist->setMinimumHeight(150);

  int w = QMAX(soundlist->sizeHint().width(), eventlist->sizeHint().width());

  soundlist->setMinimumWidth(w);
  listLayout->addWidget(soundlist, 1);

 eventlist->setMinimumWidth(w);
  listLayout->addWidget(eventlist, 1);

  connect(eventlist, SIGNAL(highlighted(int)),
     SLOT(eventSelected(int)));

  connect(testbutton, SIGNAL(clicked()), SLOT(testClicked()));

  topLayout->addWidget(soundbox, 1);
}
void SoundWidget::setInfo(int wav)
{
  wavbox->setChecked(wav);
}

int SoundWidget::wav()
{
  return wavbox->isChecked();
}

void SoundWidget::soundSelected(int soundnum)
{

  const QString &soundfile=soundlist->text(soundnum);
  int eventnum=eventlist->currentItem();

  if(eventnum > -1)
  {
    QDict<char> *sounds=&(MW->sound->sounds);
    QString event=eventlist->text(eventnum);

    if(soundnum == 0)
      sounds->remove(event);
    else
      sounds->replace(event, soundfile.latin1());
  }
}

void SoundWidget::eventSelected(int i)
{
  QDict<char> *sounds=&(MW->sound->sounds);

  if(!(*sounds)[eventlist->text(i)])
  {
    soundlist->setCurrentItem(0);
  }
  else
  {
    QString soundfile=(*sounds)[eventlist->text(i)];

    int p=0;
    int len=soundlist->count();
    bool found=false;

    while(!found && p<len)
    {
      if(soundfile==(soundlist->text(p)))
        found=true;
      else
        p++;
    }

    if(found)
      soundlist->setCurrentItem(p);
    else
      soundlist->setCurrentItem(0);
  }

  soundlist->centerCurrentItem();
}

void SoundWidget::testClicked()
{
  int soundnum=soundlist->currentItem();

   if(soundnum > 0)
    soundpath = locate("kicq_sounds",soundlist->text(soundnum));
    KAudioPlayer::play(soundpath);
}
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
LoggingWidget::LoggingWidget(QWidget *parent) : QWidget(parent)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);

  topLayout->addSpacing(7);

  QGroupBox *logbox = new QGroupBox(i18n("Logging"), this);

  QBoxLayout *boxLayout = new QVBoxLayout(logbox, 10, 7);

  boxLayout->addSpacing(7);

  QLabel *levellabel = new QLabel(i18n("Level:"), logbox);
  levellabel->setMinimumSize(levellabel->sizeHint());
  boxLayout->addWidget(levellabel);

  levelbox = new QComboBox(logbox);
  levelbox->clear();
  levelbox->insertItem(i18n("Logging off"));
  levelbox->insertItem(i18n("Fatal messages"));
  levelbox->insertItem(i18n("Error messages"));
  levelbox->insertItem(i18n("Warning messages"));
  levelbox->insertItem(i18n("Other messages"));
  levelbox->setMinimumSize(levelbox->sizeHint());
  boxLayout->addWidget(levelbox);

  QLabel *loglabel = new QLabel(i18n("File:"), logbox);
  loglabel->setMinimumSize(loglabel->sizeHint());
  boxLayout->addWidget(loglabel);

  logline = new QLineEdit(logbox);
  logline->setMinimumSize(logline->sizeHint());
  logline->setMaximumHeight(logline->sizeHint().height());
  boxLayout->addWidget(logline, 1);

  topLayout->addWidget(logbox);
  topLayout->addStretch(1);

}

void LoggingWidget::setInfo(int lvl, const QString &logname)
{
  levelbox->setCurrentItem(lvl);
  logline->setText(logname);
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
BrowserPrefWidget::BrowserPrefWidget(QWidget *parent) : QWidget(parent)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);

  topLayout->addSpacing(7);

  QGroupBox *groupbox = new QGroupBox(i18n("MIME Bindings"), this);

  QBoxLayout *boxLayout = new QVBoxLayout(groupbox, 10, 7);

  boxLayout->addSpacing(7);

  QLabel *captionlabel = new QLabel(i18n("Browser:"), groupbox);
  captionlabel->setMinimumSize(captionlabel->sizeHint());
  boxLayout->addWidget(captionlabel);

  browserbox = new QComboBox(groupbox);
  browserbox->clear();
  browserbox->insertItem("Konqueror");
  browserbox->insertItem("Netscape Navigator");
  browserbox->insertItem("Netscape Navigator with NSS");
  browserbox->insertItem("LYNX");
  browserbox->insertItem("WGET this URL");
  browserbox->insertItem("Copy URL to Clipboard");
  browserbox->setCurrentItem(KWebBrowser::getBrowser());
  browserbox->setMinimumSize(browserbox->sizeHint());
  boxLayout->addWidget(browserbox);

  topLayout->addWidget(groupbox);
  topLayout->addStretch(1);

}

void BrowserPrefWidget::save()
{
  KWebBrowser::setBrowser(browserbox->currentItem());
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
EventsTab::EventsTab(QWidget *parent, const char *name)
: QTabWidget(parent, name)
{

}

Events::Events(QWidget *parent, const char *name)
: QWidget(parent, name)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);
  QLabel *mainlabel = new QLabel(i18n(" Events"),this);
  mainlabel->setFont(QFont("Helvetica", 12, QFont::Bold, FALSE));
  QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 0, 37, 172) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 237, 237, 237) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 0, 37, 172) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 253, 253, 253) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 253, 253, 253) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setDisabled( cg );
  mainlabel->setPalette( pal );
  mainlabel->setMinimumSize(mainlabel->sizeHint());
  topLayout->addWidget(mainlabel);
  topLayout->addSpacing(7);
  evtab = new EventsTab(this);
  topLayout->addWidget(evtab);
}
