/***************************************************************************
    description          : pref_main.cpp
    begin                : Wed Apr 12 2000
    copyright            : (C) 2000 by Florian Veskov
    email                : napalmbox@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qlayout.h>
#include <qwidgetstack.h>
#include <qheader.h>
#include "icqsound.h"
#include "pref_main.h"
#include "mainwindow.h"
#include "pref_conn.h"
#include "pref_misc.h"
#include "pref_events.h"
#include "pref_status.h"
#include "pref_quickbar.h"
#include "pref_security.h"
#include "pref_pics.h"

#include "pref_main.moc"

#define QPIX(pix) QPixmap((const char**)pix)

Preferences::Preferences() : QDialog(0, 0, TRUE)
{
//  resize(500,380);
  readsize();
  setIcon(UserIcon("setup"));

  QListViewItem *listItem;
  selected="";


  QBoxLayout *topLayout = new QVBoxLayout(this, 7);

  QBoxLayout *hLayout = new QHBoxLayout(7);
  topLayout->addLayout(hLayout, 1);

  prefList = new QListView(this);
  prefList->addColumn(i18n("Category"));
  prefList->header()->hide();
  prefList->setItemMargin( 2 );
  prefList->setAllColumnsShowFocus(true);
  prefList->setShowSortIndicator(true);
  prefList->setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
  prefList->setTreeStepSize(0);
  prefList->setSorting(0);
  prefList->setColumnWidth(0,prefList->width());
  prefList->setHScrollBarMode( QScrollView::AlwaysOff );
  hLayout->addWidget(prefList);

  QWidgetStack *ws = new QWidgetStack(this);
  hLayout->addWidget(ws, 1);

  listItem = new QListViewItem(prefList, i18n("Miscellaneous"));
  listItem->setPixmap(0,QPIX(misc_xpm));
  miscwidget = new MiscWidget(this);
  otherwidget = new OtherWidget(this);
  miscwidget->misctab->addTab(otherwidget, i18n("Misc"));
  ws->addWidget(miscwidget, 1);

  listItem = new QListViewItem(prefList, i18n("Events"));
  listItem->setPixmap(0,QPIX(event_xpm));
  event = new Events(this);
  soundwidget = new SoundWidget(this);
  loggingwidget = new LoggingWidget(this);
  browserwidget = new BrowserPrefWidget(this);
  event->evtab->addTab(soundwidget,i18n("Sound"));
  event->evtab->addTab(loggingwidget,i18n("Logging"));
  event->evtab->addTab(browserwidget,i18n("WebBrowser"));
  ws->addWidget(event, 2);

  listItem = new QListViewItem(prefList, i18n("Status Mode"));
  listItem->setPixmap(0,QPIX(stmode_xpm));
  statwidget = new StatWidget(this);
  awaywidget = new AwayWidget(this);
  statwidget->stattab->addTab(awaywidget, i18n("Status"));
  ws->addWidget(statwidget, 3);

  listItem = new QListViewItem(prefList, i18n("Connections"));
  listItem->setPixmap(0,QPIX(conn_xpm));
  conn = new Connections(this);
  userwidget = new UserWidget(this);
  serverwidget = new ServerWidget(this);
  proxywidget = new ProxyWidget(this);
  conn->conntab->addTab(userwidget,i18n("User"));
  conn->conntab->addTab(serverwidget,i18n("Server"));
  conn->conntab->addTab(proxywidget,i18n("Proxy"));
  ws->addWidget(conn, 4);

  listItem = new QListViewItem(prefList, i18n("Security & Privacy"));
  listItem->setPixmap(0,QPIX(secury_xpm));
  security = new Security(this);
  secwidget = new SecurityWidget(this);
  security->sectab->addTab(secwidget, i18n("Security"));
  ws->addWidget(security,5);

  listItem = new QListViewItem(prefList, i18n("Email"));
  listItem->setPixmap(0,QPIX(mail_xpm));

  listItem = new QListViewItem(prefList, i18n("Plugins"));
  listItem->setPixmap(0,QPIX(plugin_xpm));

  listItem = new QListViewItem(prefList, i18n("Picture"));
  listItem->setPixmap(0,QPIX(pic_xpm));

  listItem = new QListViewItem(prefList, i18n("QuickBar"));
  listItem->setPixmap(0,QPIX(quick_xpm));
  quickbarwidget = new QuickBarWidget(this);
  quickbarentry = new QuickBarEntry(this);
  quickbaredit = new QuickBarEdit(this);
  quickbarwidget->quickbartab->addTab(quickbarentry,i18n("Add Entry"));
  quickbarwidget->quickbartab->addTab(quickbaredit, i18n("Edit Entry"));
  ws->addWidget(quickbarwidget,6);

  QBoxLayout *butLayout = new QHBoxLayout(7);
  topLayout->addLayout(butLayout);

  butLayout->setSpacing( 6 );
  butLayout->setMargin( 0 );

  QPushButton *addBtn = new QPushButton(i18n("Add"), this);
  addBtn->setFixedHeight(addBtn->sizeHint().height());
  butLayout->addWidget(addBtn);

  QPushButton *removeBtn = new QPushButton(i18n("Remove"), this);
  removeBtn->setFixedHeight(removeBtn->sizeHint().height());
  butLayout->addWidget(removeBtn);

  QSpacerItem* spacer = new QSpacerItem( 180, 20, QSizePolicy::Expanding, QSizePolicy::Fixed );

  butLayout->addItem( spacer );

  QPushButton *okBtn = new QPushButton(i18n("Ok"), this);
  okBtn->setFixedHeight(okBtn->sizeHint().height());
  connect(okBtn, SIGNAL(clicked()), SLOT(accept()));
  butLayout->addWidget(okBtn);

  QPushButton *cancelBtn = new QPushButton(i18n("Cancel"), this);
  cancelBtn->setFixedHeight(cancelBtn->sizeHint().height());
  connect(cancelBtn, SIGNAL(clicked()), SLOT(reject()));
  butLayout->addWidget(cancelBtn);

  int w = QMAX(okBtn->sizeHint().width(), cancelBtn->sizeHint().width());
  okBtn->setFixedWidth(w);
  cancelBtn->setFixedWidth(w);

  prefList->setMinimumSize(prefList->sizeHint()+QSize(4, 4));

  butLayout->addStretch(1);

  connect(prefList, SIGNAL(currentChanged(QListViewItem*)), this, SLOT(curChanged(QListViewItem*)));
  connect(this, SIGNAL(changedWidget(QWidget*)), ws, SLOT(raiseWidget(QWidget*)));

   prefList->setSelected(listItem, TRUE);

}

Preferences::~Preferences()
{
}

void Preferences::closeEvent(QCloseEvent *ce)
{
  savesize();
  ce->accept();
}

void Preferences::readsize()
{
  db->setPath( MW->getOwnerPath() + "/Geometry/Preferences" );

  int w = db->readEntry("width").toInt();
  int h = db->readEntry("height").toInt();
  int x = db->readEntry("x").toInt();
  int y = db->readEntry("y").toInt();

  resize(QSize(w, h));
  move(QPoint(x, y));
}

void Preferences::savesize()
{
  db->setPath( MW->getOwnerPath() + "/Geometry/Preferences" );

  db->writeEntry("width", this->width());
  db->writeEntry("height", this->height());
  db->writeEntry("x", this->x());
  db->writeEntry("y", this->y());

  db->flush();
}

void Preferences::setOwner(unsigned long uin, const QString &nick, const QString &pass)
{
  userwidget->setInfo(uin, nick, pass);
}

unsigned long Preferences::getOwner()
{
  return userwidget->uin();
}

void Preferences::setServer(const QString &host, int port)
{
  serverwidget->setInfo(host, port);
}

void Preferences::setProxy(int use, const QString &host, unsigned short port, int auth, const QString &user, const QString &pass)
{
  proxywidget->setInfo(use, host, port, auth, user, pass);
}

void Preferences::setLogging(int lvl, const QString &logfile)
{
  loggingwidget->setInfo(lvl, logfile);
}

void Preferences::setSound(bool wav, bool clear)
{
  soundwidget->setInfo(wav);
  if(clear)
    MW->sound->clear();
}

void Preferences::setOther(int rus, int clsrpl, int crlf, int quote, int recon)
{
  otherwidget->setInfo(rus, clsrpl, crlf, quote, recon);
}

void Preferences::setAway(int awaytimeout, int natimeout, bool awayenable, bool awaytona)
{
  awaywidget->setInfo(awaytimeout, natimeout, awayenable, awaytona);
}
void Preferences::setDefault()
{
  setOwner(0, "", "");
  setServer("icq.mirabilis.com", 4000);
  setProxy(FALSE, "", 1080, FALSE, "", "");
  setLogging(0, "");
  setSound(FALSE, TRUE);
  setOther(FALSE, TRUE, TRUE, FALSE, TRUE);
  setAway(30, 30, TRUE, TRUE);
}

void Preferences::accept()
{
  QDialog::accept();
  MW->saveConfigOwner(userwidget->nick(), userwidget->pass());
  MW->saveConfigServer(serverwidget->host(),serverwidget->port());
  MW->saveConfigProxy(proxywidget->use(), proxywidget->host(), proxywidget->port(),
                      proxywidget->auth(),proxywidget->user(),proxywidget->pass());
  MW->saveConfigLog(loggingwidget->level(),loggingwidget->logfile());
  MW->saveConfigSound(soundwidget->wav());
  MW->saveConfigOther(otherwidget->rus(), otherwidget->closereply(),
                      otherwidget->crlf(), otherwidget->quote(),
                      otherwidget->reconnect());
  MW->saveConfigAway(awaywidget->away(), awaywidget->na(), awaywidget->enable(),
                     awaywidget->awaytona());
  browserwidget->save();
}


void Preferences::curChanged(QListViewItem *listItem)
{

QString s(listItem->text(0));
  QWidget *w = NULL;

         if(s == i18n("Events"))             w = event;
    else if(s == i18n("Connections"))        w = conn;
    else if(s == i18n("Status Mode"))        w = statwidget;
    else if(s == i18n("Miscellaneous"))      w = miscwidget;
    else if(s == i18n("QuickBar"))           w = quickbarwidget;
    else if(s == i18n("Security & Privacy")) w = security;

    if(w) changedWidget(w);

}
