/***************************************************************************
    description          : pref_quickbar.cpp
    begin                : Mon Jul 24 2000
    copyright            : (C) 2000 by Florian Veskov
    email                : napalmbox@icqmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qlayout.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlistbox.h>
#include <qlabel.h>
#include <qfileinfo.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <kicondialog.h>
#include <kfiledialog.h>
#include <kiconloader.h>
#include <kapp.h>
#include <klocale.h>
#include <kconfig.h>
#include <kmessagebox.h>

#include "pref_quickbar.h"

#include "pref_quickbar.moc"

QuickBarEntry::QuickBarEntry(QWidget *parent) : QWidget(parent)
{

    QWhatsThis::add(this, i18n("Here You Can Add an Executable as QuickBar Button"));
	  tools_listbox = new QListBox(this);
	  tools_listbox->setGeometry( 10, 10, 170, 150);
	  connect( tools_listbox, SIGNAL(highlighted(int)),this, SLOT(slotShowToolProp(int)) );
	  tools_listbox->setFrameStyle( 51 );
	  tools_listbox->setLineWidth( 2 );
	  readConfig();

	  add_button = new QPushButton( this );
	  add_button->setGeometry( 220, 10, 100, 20 );
	  connect( add_button, SIGNAL(clicked()), this, SLOT(slotToolAdd()) );
	  add_button->setText(i18n( "&Add" ));
	  add_button->setAutoRepeat( FALSE );
	  add_button->setAutoResize( FALSE );
    QToolTip::add(add_button, i18n("Click here to add a tool specified below."));

	  delete_button = new QPushButton( this );
	  delete_button->setGeometry( 220, 45, 100,20 );
	  connect( delete_button, SIGNAL(clicked()),this, SLOT(slotToolDelete()) );
	  delete_button->setText(i18n( "De&lete" ));
	  delete_button->setAutoRepeat( FALSE );
	  delete_button->setAutoResize( FALSE );
	  delete_button->setEnabled( FALSE );
	  QToolTip::add(delete_button, i18n("Click here to delete an entry from the list."));

	  move_up_button = new QPushButton( this );
	  move_up_button->setGeometry( 220, 90, 100, 20 );
	  connect( move_up_button, SIGNAL(clicked()),this, SLOT(slotToolMoveUp()) );
	  move_up_button->setText(i18n( "Move &Up" ));
	  move_up_button->setAutoRepeat( FALSE );
	  move_up_button->setAutoResize( FALSE );
	  move_up_button->setEnabled( FALSE );
	  QToolTip::add(move_up_button, i18n("Click here to move up the selected entry."));

	  move_down_button = new QPushButton( this, "move_down_button" );
	  move_down_button->setGeometry( 220, 130, 100, 20 );
	  connect( move_down_button, SIGNAL(clicked()), this, SLOT(slotToolMoveDown()) );
	  move_down_button->setText(i18n( "Move &Down" ));
	  move_down_button->setAutoRepeat( FALSE );
	  move_down_button->setAutoResize( FALSE );
	  move_down_button->setEnabled( FALSE );
	  QToolTip::add(move_down_button, i18n("Click here to move down the selected entry."));

	  executable_label = new QLabel( this, "command_label" );
	  executable_label->setGeometry( 10, 170, 70, 20 );
	  executable_label->setText(i18n( "Executable:" ));
	  executable_label->setAlignment( 289 );
	  executable_label->setMargin( -1 );

	  executable_edit = new QLineEdit( this, "LineEdit_1" );
	  executable_edit->setGeometry( 90, 170, 210, 20 );
	  executable_edit->setText( "" );
	  executable_edit->setMaxLength( 32767 );
	  executable_edit->setEchoMode( QLineEdit::Normal );
	  executable_edit->setFrame( TRUE );
	
	  executable_button = new QPushButton( this, "executable_button" );
	  executable_button->setGeometry( 310, 170, 20, 20 );
	  QToolTip::add(executable_button, i18n("Here you can browse through the disk\n"
                                                "to select an executable file."));
	  connect( executable_button, SIGNAL(clicked()), this, SLOT(slotToolsExeSelect()) );
	  executable_button->setPixmap(BarIcon("exec"));
	  executable_button->setAutoRepeat( FALSE );
	  executable_button->setAutoResize( FALSE );

        QString text;
        text = i18n("Enter the name of the executable file here.");
        QToolTip::add(executable_edit, text);
        QToolTip::add(executable_button, text);

	  menu_text_label = new QLabel( this, "Label_3" );
	  menu_text_label->setGeometry( 10, 200, 70, 20 );
	  menu_text_label->setText(i18n( "Entry Name:" ));
	  menu_text_label->setAlignment( 289 );
	  menu_text_label->setMargin( -1 );

	  menu_text_edit = new QLineEdit( this, "LineEdit_2" );
	  menu_text_edit->setGeometry( 90, 200, 210, 20 );
	  menu_text_edit->setText( "" );
	  menu_text_edit->setMaxLength( 32767 );
	  menu_text_edit->setEchoMode( QLineEdit::Normal );
	  menu_text_edit->setFrame( TRUE );

        text = i18n("Enter a entry name for the executable here.");
	  QToolTip::add(menu_text_label, text);
        QToolTip::add(menu_text_edit, text);

    icon_button = new QPushButton( this, "icon_button");
    icon_button->setGeometry(310, 200, 20, 20);
    QToolTip::add(icon_button, i18n("Here you can browse through the disk\n"
                                                "to select an icon for entry."));
    connect( icon_button, SIGNAL(clicked()), this, SLOT(slotToolsIconSelect()) );
    icon_button->setPixmap(BarIcon("icons"));
    icon_button->setAutoRepeat( FALSE );
    icon_button->setAutoResize( FALSE );

	  ok_button = new QPushButton( this, "ok_button" );
	  ok_button->setGeometry( 10, 240, 100, 20 );
	  connect( ok_button, SIGNAL(clicked()), this, SLOT(slotOK()) );
	  ok_button->setText(i18n( "OK" ));
	  ok_button->setAutoRepeat( FALSE );
	  ok_button->setAutoResize( FALSE );
	  ok_button->setDefault( TRUE );

	  cancel_button = new QPushButton( this, "cancel_button" );
	  cancel_button->setGeometry( 130, 240, 100, 20 );
	 // connect( cancel_button, SIGNAL(clicked()), this, SLOT(reject()) );
	  cancel_button->setText(i18n( "Cancel" ));
	  cancel_button->setAutoRepeat( FALSE );
	  cancel_button->setAutoResize( FALSE );

	  help_button = new QPushButton( this, "PushButton_7" );
	  help_button->setGeometry( 240, 240, 100, 20 );
	  connect( help_button, SIGNAL(clicked()), this, SLOT(slotHelp()) );
	  help_button->setText(i18n( "&Help" ));
	  help_button->setAutoRepeat( FALSE );
	  help_button->setAutoResize( FALSE );


}
void QuickBarEntry::slotToolAdd()
{
	QString executable=executable_edit->text();
	QString menutext=menu_text_edit->text();
	QString exe_file=QFileInfo(executable).fileName();

	if(executable.isEmpty()){
		KMessageBox::sorry(this, i18n("You have to set an executable to add to the QuickBar first."));
		return;
	}

	if(menutext.isEmpty()){
	  KMessageBox::sorry(this, i18n("You have to insert a menuentry text to add the selected program to the QuickBar."));
	  return;
	}

	tools_listbox->insertItem(menutext);
	tools_exe.append(executable.latin1());
	tools_entry.append(menutext.latin1());
	//tools_argument.append(arguments_edit->text().latin1());
		
}


void QuickBarEntry::slotToolDelete()
{
	int current=tools_listbox->currentItem();
	if(current == -1) return;
	tools_exe.remove(current);
	tools_entry.remove(current);
	//tools_argument.remove(current);
	tools_listbox->removeItem(current);

}


void QuickBarEntry::slotToolMoveUp()
{
  int current = tools_listbox->currentItem();
  if(current == 0  || current == -1) return ;

  swap(current-1,current);
  tools_listbox->clear();
  tools_listbox->insertStrList(&tools_entry);
  tools_listbox->setCurrentItem(current-1);
  if(current-1 ==0) move_up_button->setEnabled(false);
  move_down_button->setEnabled(true);
}


void QuickBarEntry::slotToolMoveDown()
{
  int current = tools_listbox->currentItem();
  // if (current == (int)tools_listbox->count()-1 || current == -1) return;
  swap(current,current+1);
  tools_listbox->clear();
  tools_listbox->insertStrList(&tools_entry);
  tools_listbox->setCurrentItem(current+1);
  if(current+1 == (signed)tools_listbox->count()-1) {
    move_down_button->setEnabled(false);
  }
  move_up_button->setEnabled(true);
}


void QuickBarEntry::slotToolsExeSelect()
{
  KURL exe_file_name;
  exe_file_name = KFileDialog::getOpenURL();
  if (!exe_file_name.isEmpty()){
    QString exe_file=QFileInfo(exe_file_name.path()).fileName();
    if(!QFileInfo(exe_file_name.path()).isExecutable()){
      KMessageBox::error(this, i18n("The selected file is not an executable. Please choose an executable filename."));
      return;
    }
    else{
      executable_edit->setText(exe_file);
    }
  }
}

void QuickBarEntry::slotToolsIconSelect()
{
    KIconDialog *icondialog = new KIconDialog(this);
    icondialog->show();

}
void QuickBarEntry::slotShowToolProp(int index){

  executable_edit->setText(tools_exe.at(index));
  menu_text_edit->setText(tools_entry.at(index));
  //arguments_edit->setText(tools_argument.at(index));

  delete_button->setEnabled( TRUE );

  move_up_button->setEnabled( index != 0 );
  move_down_button->setEnabled( index+1 != (signed)tools_listbox->count() );
}


void QuickBarEntry::readConfig(){

  config = kapp->config();
  config->setGroup("QuickBarButtons");
  config->readListEntry("QuickBar_exe",tools_exe);
  config->readListEntry("QuickBar_entry",tools_entry);
 // config->readListEntry("QuickBar_argument",tools_argument);
  tools_listbox->insertStrList(&tools_entry);
}

void QuickBarEntry::writeConfig(){
  config->setGroup("QuickBarButtons");
  config->writeEntry("QuickBar_exe",tools_exe);
  config->writeEntry("QuickBar_entry",tools_entry);
 // config->writeEntry("QuickBar_argument",tools_argument);
}
void QuickBarEntry::slotOK()
{
  writeConfig();
  close();
}

void QuickBarEntry::slotHelp()
{
  kapp->invokeHTMLHelp("k2icq/index-2.html", "" );
}


void QuickBarEntry::swap(int item1,int item2){

  QString str1,str2;
  str1 = tools_exe.at(item1);
  str2 = tools_exe.at(item2);
  tools_exe.remove(item1);
  tools_exe.insert(item1,str2.latin1());
  tools_exe.remove(item2);
  tools_exe.insert(item2,str1.latin1());

  str1 = tools_entry.at(item1);
  str2 = tools_entry.at(item2);
  tools_entry.remove(item1);
  tools_entry.insert(item1,str2.latin1());
  tools_entry.remove(item2);
  tools_entry.insert(item2,str1.latin1());
/*
  str1 = tools_argument.at(item1);
  str2 = tools_argument.at(item2);
  tools_argument.remove(item1);
  tools_argument.insert(item1,str2.latin1());
  tools_argument.remove(item2);
  tools_argument.insert(item2,str1.latin1());
*/
}
///////////////////////////////////////////////////////////////////////////////////////////////////
QuickBarEdit::QuickBarEdit(QWidget *parent, const char *name): QWidget(parent,name)
{

}
////////////////////////////////////////////////////////////////////////////////////////////////////
QuickBarTab::QuickBarTab(QWidget *parent, const char *name)
       : QTabWidget(parent, name)
{

}
/////////////////////////////////////////////////////////////////////////////////////////////////////
QuickBarWidget::QuickBarWidget(QWidget *parent, const char *name)
: QWidget(parent, name)
{
  QBoxLayout *topLayout = new QVBoxLayout(this);
  QLabel *mainlabel = new QLabel(i18n(" QuickBar Config"),this);
  mainlabel->setFont(QFont("Helvetica", 12, QFont::Bold, FALSE));
 QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 0, 37, 172) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 237, 237, 237) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 0, 37, 172) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 253, 253, 253) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 220, 220, 220) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 253, 253, 253) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 110, 110) );
    cg.setColor( QColorGroup::Mid, QColor( 146, 146, 146) );
    cg.setColor( QColorGroup::Text, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 255, 255, 169) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setDisabled( cg );
  mainlabel->setPalette( pal );
  mainlabel->setMinimumSize(mainlabel->sizeHint());
  topLayout->addWidget(mainlabel);
  topLayout->addSpacing(7);
  quickbartab = new QuickBarTab(this);
  topLayout->addWidget(quickbartab);

}

