/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
// $Id: icqmessage.cpp,v 1.11 2000/10/15 19:21:10 davidvh Exp $
// Revision 1.1.2.1  2000/07/22 19:47:59  napalmbox
// kicq now compiles with -DQT_NO_ASCII_CAST
//
// Revision 1.1  2000/06/17 17:39:28  denis
// Contact List code was rewritten from scratch! Although we are trying
// to not add new features in anticipation of the next stable release,
// but this rewrite solves many things, removes many hacks and stabilizes
// whole program.
// One of bug, needs to mention, is an absence of IP address in Info
// window. The root of problem was in Contact List, because in any time
// there were several ContactItems in memory for single user - they were
// "smeared" on the whole code. Now it's clean and strict - all Contact
// List operations can be done only by ContactList class.
//
// Revision 1.1  2000/05/24 16:58:07  denis
// Sources have been splitted to the whole bunch of appropriate
// directories. Every directory is end up with static library. All
// of them are linked together to the final kicq binary.
//
// Revision 1.20  2000/05/05 03:38:48  bills
// added member variable for filesize, added accessors for file and filesize,
// added code to save method to save filesize for MSG_FILE_REQ_RECV
//
// Revision 1.19  2000/03/30 14:38:37  denis
// Some indentation fixed.
//
// Revision 1.18  2000/02/03 15:53:48  bills
// added new typeString and typeTitleString methods to move message strings
// to one location
//
// Revision 1.17  2000/01/10 16:08:22  denis
// Headers reorganized for simplify dependencies and speedup compilation.
//
// Revision 1.16  1999/12/28 01:43:30  bills
// added new code to handle file transfers
//
// Revision 1.15  1999/12/02 14:14:21  denis
// WebPager and EMailExpress messages handlers added.
// Try to fix Authorization request problems.
// Cleanups.
//
// Revision 1.14  1999/10/14 14:18:38  denis
// Removed i18n from history file delimiters.
//
// Revision 1.13  1999/09/29 17:31:32  denis
// "You were added" message support finished.
//
// Revision 1.12  1999/07/16 15:48:01  denis
// Cleaned up.
//
// Revision 1.11  1999/07/16 13:10:08  denis
// Internalization support added.
//
// Revision 1.10  1999/04/04 22:03:58  bills
// added support for MSG_CHAT_REQ_RECV and chat window handling
//
// Revision 1.9  1999/03/05 13:04:37  denis
// Applied patch to handle authorization request messages by Bogdan Surdu
// <tim@ima-info.ro>
//
// Revision 1.8  1998/12/11 18:20:04  whale
// Added support for MSG_AUTH_RECV (incoming auth requests)
//
// Revision 1.7  1998/12/08 16:16:50  denis
// Cleaned up a little before releasing
//

#include <stdio.h>
#include <qregexp.h>
#include <kapp.h>
#include "mainwindow.h"
#include "icqmessage.h"
#include <qmessagebox.h>
#include "uconfigdb.h"

const QString icqMessage::icqMsgTypeStrings[] = {
  "Unknown", "Message Sent", "Message Received", "URL Sent", "URL Received",
  "Authorization Requested", "Authorization Granted", "Authorization Refused",
  "Chat Request Received", "Added to Contact List", "WebPager Received",
  "EMailExpress Received", "File Request Received"
};

const QString icqMessage::icqMsgTypeTitles[] = {
  "Unknown", "Outgoing Message", "Incoming Message", "Outgoing URL",
  "Incoming URL", "Authorization Request", "Authorization Granted",
  "Authorization Refused", "Incoming Chat Request", "System Message",
  "Incoming WebPager Message", "Incoming EmailExpress Message",
  "Incoming File Request"
};

/* Message */
icqMessage::icqMessage(unsigned long uin, TimeStr time, const QString &body, icqMsgType type)
{
  msgType = type;
  msgUin = uin;
  msgTime = time;
  msgBody = body;
  msgNew = TRUE;
  msgBody.replace(QRegExp("\r"), "");
  return;
}

icqMessage::icqMessage(unsigned long uin, TimeStr time, const QString &body, unsigned long seq, icqMsgType type)
{
  msgType = type;
  msgUin = uin;
  msgTime = time;
  msgBody = body;
  msgSeq = seq;
  msgNew = TRUE;
  msgBody.replace(QRegExp("\r"), "");
  return;
}

/* MSG_FILE_REQ_RECV */
icqMessage::icqMessage(unsigned long uin, TimeStr time, const QString &body,
                       const QString &file, unsigned long size,
                       unsigned long seq, icqMsgType type)
{
  msgType = type;
  msgUin = uin;
  msgTime = time;
  msgBody = body;
  msgSeq = seq;
  msgFile = file;
  msgFileSize = size;
  msgNew = TRUE;
  return;
}

/* URL */
icqMessage::icqMessage(unsigned long uin, TimeStr time, const QString &url, const QString &desc, icqMsgType type)
{
  msgType = type;
  msgUin = uin;
  msgTime = time;
  msgBody = desc;
  msgURL = url;
  msgNew = TRUE;

  /* Ensure that there is no '\n' in URL */
  msgURL.replace(QRegExp("\n"), "");
/*  int c = 0;
    while((c = msgURL.find('\n',0)) != -1)
    msgURL.remove(c,1);*/
  return;
}

icqMessage::icqMessage(unsigned long uin, TimeStr time, const QString &nick, const QString &first,
                       const QString &last, const QString &email, const QString &reason, icqMsgType type)
{
  msgType = type;
  msgUin = uin;
  msgTime = time;
  msgBody = reason;
  msgNick = nick;
  msgFirst = first;
  msgLast = last;
  msgEmail = email;
  msgNew = TRUE;
  return;
}

icqMessage::icqMessage(unsigned long uin, TimeStr time, const QString &nick, const QString &first,
                       const QString &last, const QString &email, icqMsgType type)
{
  msgType = type;
  msgUin = uin;
  msgTime = time;
  msgNick = nick;
  msgFirst = first;
  msgLast = last;
  msgEmail = email;
  msgNew = TRUE;
  return;
}

/* Pager/Express */
icqMessage::icqMessage(unsigned long uin, TimeStr time, const QString &nick, const QString &email,
                       const QString &body, icqMsgType type)
{
  msgType = type;
  msgUin = uin;
  msgTime = time;
  msgNick = nick;
  msgEmail = email;
  msgBody = body;
  msgNew = TRUE;
  return;
}

icqMessage::icqMessage(icqMessage *msg)
{
  msgType = msg->type();
  msgUin = msg->uin();
  msgTime = msg->time();
  msgBody = msg->body();
  msgURL = msg->url();
  msgNew = msg->isNew();
  return;
}

void icqMessage::expire(void)
{
  msgNew = 0;
  return;
}

void icqMessage::setType(icqMsgType type)
{
  msgType = type;
  return;
}

void icqMessage::save(void)
{
  Q_UINT32 total;

  db->setPath(MW->getOwnerPath() + "/Contact List/" + QString::number(msgUin) + "/History");

  if(!db->readEntry("Total", total))
    total = 0;

  db->writeEntry(total, true);

  db->setPath("Type");
  db->writeEntry(total, (Q_UINT32)msgType);
  
  db->setPath("../msgNew");
  db->writeEntry(total, msgNew);

  db->setPath("../msgUin");
  db->writeEntry(total, (Q_UINT32)msgUin);

  db->setPath("../msgBody");
  db->writeEntry(total, msgBody);

  db->setPath("../msgURL");
  db->writeEntry(total, msgURL);

  db->setPath("../msgNick");
  db->writeEntry(total, msgNick);

  db->setPath("../msgFirst");
  db->writeEntry(total, msgFirst);

  db->setPath("../msgLast");
  db->writeEntry(total, msgLast);

  db->setPath("../msgEmail");
  db->writeEntry(total, msgEmail);

  db->setPath("../msgFile");
  db->writeEntry(total, msgFile);

  db->setPath("../msgFileSize");
  db->writeEntry(total, (Q_UINT32)msgFileSize);

  db->setPath("../msgSeq");
  db->writeEntry(total, (Q_UINT32)msgSeq);

  db->setPath("../msgTime");
  db->writeStream(total) << msgTime.hour
                         << msgTime.minute
                         << msgTime.day
                         << msgTime.month
                         << msgTime.year;

  db->setPath("..");
  db->writeEntry("Total", ++total);  // Increase megs number.

  db->flush(true); // Clean UConfig caches (necessary for UConfig 1.0)
  return;
}

bool icqMessage::load(Q_UINT32 n)
{
  /////////////////////
  // Path must be set.
  /////////////////////
  Q_UINT32 mt, uin, fileSize, seq;

  db->setPath("Type");
  if(!db->readEntry(n, mt)) return false;
  
  db->setPath("../msgNew");
  if(!db->readEntry(n, msgNew)) return false;

  db->setPath("../msgUin");
  if(!db->readEntry(n, uin)) return false;

  db->setPath("../msgBody");
  if(!db->readEntry(n, msgBody)) return false;

  db->setPath("../msgURL");
  if(!db->readEntry(n, msgURL)) return false;

  db->setPath("../msgNick");
  if(!db->readEntry(n, msgNick)) return false;

  db->setPath("../msgFirst");
  if(!db->readEntry(n, msgFirst)) return false;

  db->setPath("../msgLast");
  if(!db->readEntry(n, msgLast)) return false;

  db->setPath("../msgEmail");
  if(!db->readEntry(n, msgEmail)) return false;

  db->setPath("../msgFile");
  if(!db->readEntry(n, msgFile)) return false;

  db->setPath("../msgFileSize");
  if(!db->readEntry(n, fileSize)) return false;

  db->setPath("../msgSeq");
  if(!db->readEntry(n, seq)) return false;

  db->setPath("../msgTime");
  db->readStream(n) >> msgTime.hour
                    >> msgTime.minute
                    >> msgTime.day
                    >> msgTime.month
                    >> msgTime.year;
  
  msgType     = (icqMsgType)mt;
  msgUin      = (unsigned long)uin;
  msgFileSize = (unsigned long)fileSize;
  msgSeq      = (unsigned long)seq;

  db->setPath("..");
  return true;
}
